==> kara-uc-1.1.66.tgz: package/src/kara-uc/components/UCInfo/intro/index.js <==
import React from 'react'
import tost from "kara-module-tost";
import css from '../index.scss'

export default class Intro extends React.Component {
  constructor(props) {
    super(props)
    this.state = {
      editSign: false,
      changeIntro: '',
    }
    this.inputSign = React.createRef()
  }

  editSignature = () => {
    this.setState({editSign: !this.state.editSign}, () => {
      this.inputSign.current.focus()
    })
  }

  introUpdateSign = (e) => {
    const value = e.target.value
    const {signature = '', httpAgent, updateSign, lang} = this.props
    if (value.trim() !== signature && this.state.editSign) {
      httpAgent.post('/sdm/signature', {
        content: value
      }).then(
        res => {
          if (res && res.resultCode && res.resultCode === '000000') {
            updateSign(value)
            tost({type: 'success', msg: lang.updateSuccess, time: 4})
          }
          else {
            tost({type: 'error', msg: lang.updateError, time: 4})
          }
        }
      )
    }

    this.setState({editSign: false})
  }

  onChangeIntro = (e) => {
    const {lang} = this.props
    const value = e.target.value
    if (value.length >= 50) {
      tost({type: 'warn', msg: lang.noMore50})
    } else {
      this.setState({changeIntro: value})
    }
  }

  onKeyDownIntro = (e) => {
    if (e.which === 13) {
      this.introUpdateSign(e)
    }
  }

  render() {
    const {changeIntro} = this.state
    const {signature, lang} = this.props
    return (<div className="clearfix">
      <span className='s-hint'>{lang.intro}</span>
      <span className={this.state.editSign ? css.hide : ''}
            onClick={this.editSignature}>{signature || lang.noIntro}</span>
      <span className={`${!this.state.editSign ? css.hide : ''} ${css.introSpan}`}>
            <textarea
              maxLength="50" cols="30" rows="2"
              ref={this.inputSign}
              className='s-b-primary'
              defaultValue={changeIntro === '' ? signature : changeIntro}
              onBlur={this.introUpdateSign}
              onChange={this.onChangeIntro}
              onKeyPress={this.onKeyDownIntro}
            />
            </span>
      {/*<span className='s-primary' onClick={this.editSignature}><i*/}
      {/*className='kuc-iconfont kuc-edit'></i>&nbsp;&nbsp;{lang.edit}</span>*/}
    </div>)
  }
}

==> kara-uc-1.2.28.tgz: package/src/kara-uc/components/UCInfo/intro/index.js <==
import React from 'react'
import {Tost} from 'karaui'
import css from '../index.scss'

export default class Intro extends React.Component {
  constructor(props) {
    super(props)
    this.state = {
      editSign: false,
      changeIntro: '',
    }
    this.inputSign = React.createRef()
  }

  editSignature = () => {
    this.setState({editSign: !this.state.editSign}, () => {
      this.inputSign.current.focus()
    })
  }

  introUpdateSign = (e) => {
    const value = e.target.value
    const {signature = '', httpAgent, updateSign, lang} = this.props
    if (value.trim() !== signature && this.state.editSign) {
      httpAgent.post('/sdm/signature', {
        content: value
      }).then(
        res => {
          if (res && res.resultCode && res.resultCode === '000000') {
            updateSign(value)
            Tost({type: 'success', msg: lang.updateSuccess, time: 4})
          }
          else {
            Tost({type: 'error', msg: lang.updateError, time: 4})
          }
        }
      )
    }

    this.setState({editSign: false})
  }

  onChangeIntro = (e) => {
    const {lang} = this.props
    const value = e.target.value
    if (value.length >= 50) {
      Tost({type: 'warn', msg: lang.noMore50})
    } else {
      this.setState({changeIntro: value})
    }
  }

  onKeyDownIntro = (e) => {
    if (e.which === 13) {
      this.introUpdateSign(e)
    }
  }

  render() {
    const {changeIntro} = this.state
    const {signature, lang} = this.props
    return (<div className="clearfix">
      <span className='s-hint'>{lang.intro}</span>
      <span className={this.state.editSign ? css.hide : ''}
            onClick={this.editSignature}>{signature || lang.noIntro}</span>
      <span className={`${!this.state.editSign ? css.hide : ''} ${css.introSpan}`}>
            <textarea
              maxLength="50" cols="30" rows="2"
              ref={this.inputSign}
              className='s-b-primary'
              defaultValue={changeIntro === '' ? signature : changeIntro}
              onBlur={this.introUpdateSign}
              onChange={this.onChangeIntro}
              onKeyPress={this.onKeyDownIntro}
            />
            </span>
      {/*<span className='s-primary' onClick={this.editSignature}><i*/}
      {/*className='kuc-iconfont kuc-edit'></i>&nbsp;&nbsp;{lang.edit}</span>*/}
    </div>)
  }
}
